@@ -1,6 +1,6 @@
 -- CRC24.hs: OpenPGP (RFC4880) CRC24 implementation
--- Copyright © 2012  Clint Adams
--- This software is released under the terms of the ISC license.
+-- Copyright © 2012-2019 Clint Adams
+-- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
 module Data.Digest.CRC24 (
@@ -27,4 +27,4 @@ crc24 :: B.ByteString -> Word32
 crc24 bs = crc24Lazy . BL.fromChunks $ [bs]
 
 crc24Lazy :: ByteString -> Word32
-crc24Lazy = BL.foldl crc24Update crc24Init
+crc24Lazy = BL.foldl' crc24Update crc24Init
