@@ -1,6 +1,6 @@
 -- mark.hs: openpgp-asciiarmor benchmark suite
--- Copyright © 2018  Clint Adams
--- This software is released under the terms of the ISC license.
+-- Copyright © 2018-2019 Clint Adams
+-- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
 {-# LANGUAGE FlexibleContexts, OverloadedStrings #-}
@@ -11,6 +11,8 @@ import Data.Digest.CRC24
 
 main :: IO ()
 main = defaultMain [
-  bgroup "crc" [ bench "crc24"  $ whnf crc24 "test"
+  bgroup "crc" [
+                 bench "crc24"  $ whnf crc24 "test"
+               , bench "crc24Lazy"  $ whnf crc24Lazy "test"
                ]
                    ]
